pub struct MatchMark {
pub require_hanja: bool,
pub require_hangul: bool,
}Expand description
Dictionary-provided rendering constraints for a match.
Fields
require_hanja: boolWhether this dictionary entry should always show its hanja form.
require_hangul: boolWhether this dictionary entry should always show its hangul reading.